@@ -657,6 +657,7 @@ gpgsm_verify (ctrl_t ctrl, estream_t in_fp, estream_t data_fp,
         /* Handle the --assert-signer option.  */
         check_assert_signer_list (ctrl, fpr);
         xfree (fpr);
+        /* Print the status line.  */
         gpgsm_status (ctrl, STATUS_VALIDSIG, buf);
         xfree (buf);
       }
@@ -703,7 +704,7 @@ gpgsm_verify (ctrl_t ctrl, estream_t in_fp, estream_t data_fp,
             if (*qualbuffer)
               {
                 log_info (_("This is a qualified signature\n"));
-                if (!opt.qualsig_approval)
+                if (!opt.qualsig_approval && !opt.no_qes_note)
                   log_info
                     (_("Note, that this software is not officially approved "
                        "to create or verify such signatures.\n"));
@@ -714,6 +715,10 @@ gpgsm_verify (ctrl_t ctrl, estream_t in_fp, estream_t data_fp,
                      gpg_strerror (rc));
       }
 
+      /* Handle the --assert-validsig option.  */
+      if (opt.assert_validsig)
+        assert_validsig_true = 1;
+
       gpgsm_status (ctrl, STATUS_TRUST_FULLY,
                     (verifyflags & VALIDATE_FLAG_STEED)?
                     "0 steed":
